/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.structure;

import de.unibi.techfak.isy.lppba.descriptors.Sentence;
import de.unibi.techfak.isy.lppba.descriptors.Token;
import edu.stanford.nlp.ling.HasWord;
import edu.stanford.nlp.ling.TaggedWord;
import edu.stanford.nlp.tagger.maxent.MaxentTagger;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;
import org.apache.uima.analysis_engine.AnalysisEngineProcessException;
import org.apache.uima.jcas.JCas;

/**
 * This uses the Stanford POS Tagger to tokenize sentences and words and give the words a POS
 * feature.
 *
 * The code is derived from the TaggerDemo given by Stanford itself.
 * 
 * The part of speech tags given by the Stanford tagger are described here:
 * 
 * http://www.ling.upenn.edu/courses/Fall_2003/ling001/penn_treebank_pos.html
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class StanfordTokenizer extends
	org.apache.uima.fit.component.JCasAnnotator_ImplBase {

	private static final MaxentTagger tagger = new MaxentTagger(
		"importdata/english-left3words-distsim.tagger");

	public StanfordTokenizer() {
	}

	@Override
	public void process(JCas jcas) throws AnalysisEngineProcessException {
		final List<List<HasWord>> sentences
			= MaxentTagger.tokenizeText(new StringReader(jcas.getDocumentText()));
		for (final List<HasWord> sentence : sentences) {
			final ArrayList<TaggedWord> tSentence = tagger.tagSentence(sentence);
			if (!tSentence.isEmpty()) {
				//annotate a sentence with first and last word.
				final int sentenceStart = tSentence.get(0).beginPosition();
				final int sentenceEnd = tSentence.get(tSentence.size() - 1).endPosition();
				final Sentence uimaSentence = new Sentence(jcas, sentenceStart, sentenceEnd);
				uimaSentence.addToIndexes();
				for(final TaggedWord tWord : tSentence){
					final Token uimaWord = new Token(jcas, tWord.beginPosition(), tWord.endPosition());
					uimaWord.setPOS(tWord.tag());
					uimaWord.addToIndexes();
				}
			}
		}
	}

}
