/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.db;

import de.unibi.techfak.scie.configuration.ConfigurationSet;
import de.unibi.techfak.scie.ontology.OntologyDatabase;
import de.unibi.techfak.scie.ontology.driver.OntologyDatabaseDriver;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public abstract class DatabaseInstance {

	public static final String SCHEMA_CONFIG_COMMENT = "LPPBA DB Schema Versions";

	public static final String SCHEMA_KEY_ONTOLOGY = "ontology_db_schema_version";

	public static final String SCHEMA_DEFAULT_VERSION = "0000-00-00.00";

	protected final ConfigurationSet config;

	public DatabaseInstance(ConfigurationSet configuration) {
		this.config = configuration;
	}

	public abstract OntologyDatabase getOntologyDatabase();

	public abstract OntologyDatabaseDriver getOntologyDatabaseDriver();

	public abstract void close();

	public void ensureSchema() {
		// Load the schema version file
		final String filename = "./.schema_version_"
				+ config.getConfiguration().configurationHash() + ".prop";
		final File schemaConfigFile = new File(filename);
		final Properties schemaConfig = new Properties();
		try {
			schemaConfig.load(new FileInputStream(schemaConfigFile));
		} catch (IOException ex) {
			// Everything is fine here, the property file may be damaged or
			// not-existant
		}

		// Read the ontology db version
		String ontologyDBVersion = schemaConfig.getProperty(
				SCHEMA_KEY_ONTOLOGY, SCHEMA_DEFAULT_VERSION);
		OntologyDatabaseDriver ontologyDBDriver = getOntologyDatabaseDriver();
		if (!ontologyDBVersion.equals(ontologyDBDriver.getSchemaVersion())) {
			System.out.println("Ontology db schema versions differ, recreating the db!");
			ontologyDBDriver.clear();
			schemaConfig.setProperty(SCHEMA_KEY_ONTOLOGY,
					ontologyDBDriver.getSchemaVersion());
		}

		try {
			// Store the config
			schemaConfig.store(new FileOutputStream(schemaConfigFile),
					SCHEMA_CONFIG_COMMENT);
		} catch (IOException ex) {
			// Do nothing here
		}
	}

}
