/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.db;

import de.unibi.techfak.scie.configuration.ConfigurationSet;
import de.unibi.techfak.scie.ontology.OntologyDatabase;
import de.unibi.techfak.scie.ontology.driver.OntologyDatabaseDriver;
import de.unibi.techfak.scie.ontology.driver.implementation.JDBCDatabaseDriver;
import de.unibi.techfak.scie.ontology.driver.implementation.SQLStatements;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public abstract class JDBCDatabaseInstance extends DatabaseInstance {

	private Connection connection = null;

	private JDBCDatabaseDriver ontologyDatabaseDriver = null;

	private OntologyDatabase ontologyDatabase = null;

	public JDBCDatabaseInstance(ConfigurationSet configuration) {
		super(configuration);
	}

	protected Connection getConnection() {
		try {
			if (connection == null) {
				final String url = getURL();
				final Properties props = getProperties();
				connection = DriverManager.getConnection(url, props);
			}
			return connection;
		} catch (SQLException ex) {
			throw new RuntimeException(ex);
		}
	}

	@Override
	public OntologyDatabaseDriver getOntologyDatabaseDriver() {
		if (ontologyDatabaseDriver == null) {
			final Connection c = getConnection();
			ontologyDatabaseDriver = new JDBCDatabaseDriver(c, getStatements(c));
			try {
				ontologyDatabaseDriver.initializeSchema();
			} catch (SQLException ex) {
				throw new RuntimeException(ex);
			}
		}
		return ontologyDatabaseDriver;
	}

	@Override
	public OntologyDatabase getOntologyDatabase() {
		if (ontologyDatabase == null) {
			
			ontologyDatabase = new OntologyDatabase(getOntologyDatabaseDriver());
		}
		return ontologyDatabase;
	}

	@Override
	public void close() {
		try {
			connection.close();
		} catch (SQLException ex) {
			// We wanted to close the connection anyways
		}
	}

	protected abstract SQLStatements getStatements(Connection c);

	protected abstract String getURL();

	protected abstract Properties getProperties();

}
