/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.document_import;

import de.unibi.techfak.scie.annotators.structure.StructureAnnotator;
import de.unibi.techfak.scie.pdfextractor.PDFStructuredTextExtractor;
import java.io.IOException;
import java.io.InputStream;
import org.apache.uima.analysis_engine.AnalysisEngineProcessException;
import org.apache.uima.jcas.JCas;

/**
 * This class is a wrapper for the SCIE PDFTextExtractor.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 *
 */
public class PDFStructuredTextExtractorWrapper extends DocumentImporter {

	public PDFStructuredTextExtractorWrapper(InputStream input, JCas target) {
		super(input, target);
	}

	@Override
	public void doImport() throws IOException {
		//Use the PDFStructuredTextExctractor from the included package.
		final PDFStructuredTextExtractor textExtractor =
				new PDFStructuredTextExtractor(input);
		de.unibi.techfak.scie.pdfextractor.structure.Document outDoc = textExtractor.doImport();
		

		// transform to output text and index all objects in the hiararchy.
		final String docText = outDoc.indexedToString(0);
		target.setDocumentText(docText);

		// copy the structure information to the UIMA handling.
		final StructureAnnotator structureAnnotator =
				new StructureAnnotator(outDoc);
		try {
			structureAnnotator.process(target);
		} catch (AnalysisEngineProcessException ex) {
			throw new IOException(ex);
		}
	}
}
