/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.dictionary_name_finder;

import de.unibi.techfak.scie.util.LineSegment;
import de.unibi.techfak.scie.ontology.DictionaryMatch;
import de.unibi.techfak.scie.probability_model.AnnotationCandidate;

/**
 * The WordReference class is used to connect a dictionary query result (match)
 * to the underlying
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
class WordReference extends LineSegment implements AnnotationCandidate {

	private final DictionaryMatch match;

	public WordReference(int begin, int end, DictionaryMatch match) {
		super(begin, end);
		this.match = match;
	}

	public DictionaryMatch getMatch() {
		return match;
	}

	/**
	 * Inserts a word reference into the dictionary match and increases the
	 * begin and end of the match accordingly.
	 *
	 * @param wordRef is the word reference for which the text should be
	 * extended.
	 * @param p
	 */
	public void expandDictionaryMatch(DictionaryMatch match, double p) {
		match.setBegin(Math.min(match.getBegin(), this.begin));
		match.setEnd(Math.max(match.getEnd(), this.end));
		match.setProbability(match.getProbability() + p);
	}

}
