/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.driver.implementation;

import java.sql.Connection;

/**
 * Contains all deviations between the sql statements listed in the
 * DefaultSQLStatements class and the statements needed for a PostgreSQL DB.
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public class PostgreSQLStatements extends DefaultSQLStatements {

	public PostgreSQLStatements(Connection connection) {
		super(connection);
	}

	@Override
	public String[] getSchemaSQLForTable(String table) {
		switch (table) {
			case TBL_ASSOCIATIONS:
				return new String[]{
					"CREATE TABLE " + TBL_ASSOCIATIONS + " ("
					+ "oid INT, "
					+ "src INT, "
					+ "tar INT, "
					+ "type INT)",
					"CREATE INDEX " + TBL_ASSOCIATIONS + "_index ON " + TBL_ASSOCIATIONS + " ("
					+ "oid, "
					+ "src, "
					+ "tar, "
					+ "type)"
				};
			case TBL_DICTIONARY:
				return new String[]{
					"CREATE TABLE " + TBL_DICTIONARY + " ("
					+ "oid INT, "
					+ "id INT, "
					+ "entry VARCHAR(255))",
					"CREATE INDEX " + TBL_DICTIONARY + "_index ON " + TBL_DICTIONARY + " ("
					+ "entry)"
				};
			case TBL_NODES:
				return new String[]{
					"CREATE TABLE " + TBL_NODES + " ("
					+ "oid INT, "
					+ "id INT, "
					+ "root BOOLEAN)",
					"CREATE INDEX " + TBL_NODES + "_index ON " + TBL_NODES + " ("
					+ "oid, "
					+ "id, "
					+ "root)"
				};
			case TBL_NODE_NAMES:
				return new String[]{
					"CREATE TABLE " + TBL_NODE_NAMES + " ("
					+ "oid INT, "
					+ "id INT, "
					+ "mode INT, "
					+ "prim BOOLEAN, "
					+ "name VARCHAR(255), "
					+ "type VARCHAR(255))",
					"CREATE INDEX " + TBL_NODE_NAMES + "_index ON " + TBL_NODE_NAMES + " ("
					+ "oid, "
					+ "id)"
				};
			case TBL_ONTOLOGIES:
				return new String[]{
					"CREATE TABLE " + TBL_ONTOLOGIES + " ("
					+ "name VARCHAR(255), "
					+ "id SERIAL, "
					+ "mdate TIMESTAMP DEFAULT CURRENT_TIMESTAMP)",
					"CREATE INDEX " + TBL_ONTOLOGIES + "_index ON " + TBL_ONTOLOGIES + " ("
					+ "id)"
				};
			default:
				return new String[]{};
		}
	}

}
