/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.probability_model.uima;

import de.unibi.techfak.scie.probability_model.AnnotationCandidate;
import de.unibi.techfak.scie.probability_model.AnnotationCompositor;
import de.unibi.techfak.scie.probability_model.ProbableHypothesis;
import de.unibi.techfak.scie.probability_model.uima.UIMAAnnotationCompositionUtil.UIMAAnnotationCandidate;
import java.util.ArrayList;
import org.apache.uima.jcas.JCas;
import org.apache.uima.jcas.tcas.Annotation;

/**
 * This is an interface for classes that are able to compose from one candidate
 * for each attribute of a composition annotation the composition. In effect
 * this should mainly be using setter-methods.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public abstract class UIMACompositor<Y extends Annotation> implements
		AnnotationCompositor<Y> {

	private JCas jcas;

	public void setJcas(JCas jcas) {
		this.jcas = jcas;
	}

	public JCas getJcas() {
		return jcas;
	}

	@Override
	public Y compose(AnnotationCandidate core,
			ArrayList<ProbableHypothesis> slotCandidates) {
		int minBegin = core.getBegin();
		int maxEnd = core.getEnd();
		for (ProbableHypothesis hypo
				: slotCandidates) {
			if (hypo != null && hypo.getCandidate() != null) {
				final int begin = hypo.getCandidate().getBegin();
				final int end = hypo.getCandidate().getEnd();
				if (begin < minBegin) {
					minBegin = begin;
				}
				if (end > maxEnd) {
					maxEnd = end;
				}
			}
		}
		return UIMACompose(((UIMAAnnotationCandidate) core).getAnnotation(),
				slotCandidates, minBegin, maxEnd, jcas);
	}

	public abstract Y UIMACompose(Annotation core,
			ArrayList<ProbableHypothesis> slotCandidates,
			int minBegin, int maxEnd, JCas jcas);
}
