/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.animal;

import de.unibi.techfak.scie.annotators.animal.WeightAnnotator;
import de.unibi.techfak.scie.annotators.animal.LabGroupAnnotator;
import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.scie.annotators.quantities.WordNumberAnnotator;
import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.LabGroup;
import java.util.Collection;
import junit.framework.TestCase;
import org.apache.uima.analysis_engine.AnalysisEngineDescription;
import org.apache.uima.fit.factory.AnalysisEngineFactory;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.pipeline.SimplePipeline;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class LabGroupAnnotatorTest extends TestCase {

	public LabGroupAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class LabGroupAnnotator.
	 */
	public void testProcess() throws Exception {
		DatabaseSingleton.initialize("./config.xml");

		//create example
		final JCas jcas = JCasFactory.createJCas(
			"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
			"Adult, Long-Evans female rats (Somonsen Laboratories, Gilroy, CA, USA, n=56)");
		//preprosessing
		//primitives
		final AnalysisEngineDescription stanfordTokenizer = AnalysisEngineFactory.
			createEngineDescription(StanfordTokenizer.class);
		//ontology
		final AnalysisEngineDescription ontoAnnotator = AnalysisEngineFactory.
			createEngineDescription(OntologyAnnotator.class);
		//numbers
		final AnalysisEngineDescription numberAnnotator = AnalysisEngineFactory.
			createEngineDescription(NumberAnnotator.class);
		final AnalysisEngineDescription wordNumberAnnotator = AnalysisEngineFactory.
			createEngineDescription(WordNumberAnnotator.class);
		final AnalysisEngineDescription weightAnnotator = AnalysisEngineFactory.
			createEngineDescription(WeightAnnotator.class);

		//use the lab group annotator
		final AnalysisEngineDescription instance = AnalysisEngineFactory.
			createEngineDescription(LabGroupAnnotator.class);

		SimplePipeline.runPipeline(jcas,
			stanfordTokenizer,
			numberAnnotator, wordNumberAnnotator, weightAnnotator,
			ontoAnnotator,
			instance);

		//check results
		final Collection<LabGroup> labGroups = JCasUtil.select(jcas, LabGroup.class);
		assertEquals(1, labGroups.size());
		final LabGroup labGroup = labGroups.iterator().next();
		final String exp
			= "Adult, Long-Evans female rats (Somonsen Laboratories, Gilroy, CA, USA, n=56";
		assertEquals("Expected \"" + exp + "\" but was \"" + labGroup.getCoveredText() + "\"", exp,
			labGroup.getCoveredText());
		assertNotNull(labGroup.getOrganism());
		assertEquals("Expected \"Long-Evans female rats\", but was\"" +
			labGroup.getCoveredText() + "\"",
			"Long-Evans female rats", labGroup.getOrganism().getCoveredText());
		assertNotNull(labGroup.getAge());
		assertEquals("Adult", labGroup.getAge().getCoveredText());
		assertNotNull(labGroup.getGender());
		assertEquals("female", labGroup.getGender().getCoveredText());
		assertNotNull(labGroup.getNumber());
		assertEquals("56", labGroup.getNumber().getCoveredText());
	}
}
