/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.LanguageQuantifier;
import java.util.Collection;
import java.util.Iterator;
import junit.framework.TestCase;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author socnow
 */
public class LanguageQuantifierAnnotatorTest extends TestCase {

	public LanguageQuantifierAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		DatabaseSingleton.initialize("./config.xml");
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class LanguageQuantifierAnnotator.
	 */
	public void testProcess() throws Exception {

		//initialization
		final OntologyAnnotator instance = new OntologyAnnotator();
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");

		//set up jcas
		jcas.setDocumentLanguage("en");
		jcas.setDocumentText(
				"With a few rats we did many of the experiments that had no impact at all to the great majority of the community.");
		final String[] expected = {"few", "many", "no", "all", "great"};
		//then use the OntologyAnnotator to get LanguageQuantifiers.
		instance.process(jcas);
		//check results

		final Collection<LanguageQuantifier> quantifiers =
				JCasUtil.select(jcas, LanguageQuantifier.class);
		final Iterator<LanguageQuantifier> iterator = quantifiers.iterator();

		for (int i = 0; i < expected.length; i++) {
			assertTrue(iterator.hasNext());
			assertEquals(expected[i], iterator.next().getCoveredText());
		}
		assertFalse(iterator.hasNext());
	}
}
