/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.result;

import de.unibi.techfak.scie.annotators.result.ResultAnnotator;
import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.Result;
import java.util.Collection;
import junit.framework.TestCase;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class ResultAnnotatorTest extends TestCase {

	public ResultAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		DatabaseSingleton.initialize("./config.xml");
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class ResultAnnotator.
	 */
	public void testProcess() throws Exception {

		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
				"After treatment we noticed a significant improvement in motor function.");
		//preprosess using OntologyAnnotator
		final OntologyAnnotator oa = new OntologyAnnotator();
		oa.process(jcas);

		final ResultAnnotator instance = new ResultAnnotator();
		instance.process(jcas);

		//get the result annotation with maximum probability.
		final Collection<Result> results = JCasUtil.select(jcas, Result.class);
		assertFalse(results.isEmpty());
		double maxProb = 0;
		Result maxResult = null;
		for (final Result result : results) {
			if (result.getProbability() > maxProb) {
				maxProb = result.getProbability();
				maxResult = result;
			}
		}
		assertNotNull(maxResult);

		assertEquals("significant improvement in motor function", maxResult.getCoveredText());
		assertEquals("significant", maxResult.getSignificance().getCoveredText());
		assertTrue(maxResult.getSignificance().getIsSignificant());
		assertEquals("improvement", maxResult.getTrend().getCoveredText());
		assertEquals("improvement", maxResult.getTrend().getNormalizedName());
		assertEquals("motor function", maxResult.getInvestigationMethods().getCoveredText());
		assertNull(maxResult.getPValue());

	}
}
