/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.result;

import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.Significance;
import de.unibi.techfak.isy.lppba.descriptors.Trend;

import java.util.Collection;
import java.util.HashSet;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertTrue;
import junit.framework.TestCase;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author socnow
 */
public class SignificanceAnnotatorTest extends TestCase {

	public SignificanceAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		DatabaseSingleton.initialize("./config.xml");
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class SignificanceAnnotator.
	 */
	public void testProcess() throws Exception {

		//TODO: Test this in OntologyAnnotator
		//create example
		final JCas jcas = JCasFactory.createJCas(
			"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText("significantly reduce (Conta et al. 2008)\n" +
			"    did not differ from each other, tended to be decreased, significantly smaller (Gris et al. 2005)\n" +
			"    significantly improved (Huang et al. 2009)");
		//create instance
		final OntologyAnnotator instance = new OntologyAnnotator();
		instance.process(jcas);

		//check results.
		final Collection<Significance> significances = JCasUtil.select(jcas, Significance.class);
		//this should contain "significantly" at least three times interpreted as significant.
		int correctCounter = 0;
		for (Significance significance : significances) {
			if (significance.getIsSignificant()) {
				correctCounter++;
				assertEquals("significantly", significance.getCoveredText());
			}
		}
		assertTrue(correctCounter >= 3);
		//we are also looking for trends.
		final Collection<Trend> trends = JCasUtil.select(jcas, Trend.class);
		final String[] exptected = {"reduce", "not differ", "decreased", "smaller", "improved"};
		final String[] exptectedNormalized = {"decrease", "no difference", "improvement"};
		final HashSet<String> actual = new HashSet<>();
		final HashSet<String> actualNormalized = new HashSet<>();
		for (final Trend trend : trends) {
			actual.add(trend.getCoveredText());
			actualNormalized.add(trend.getNormalizedName());
		}

		for (final String exp : exptected) {
			assertTrue(exp + " was not found!", actual.contains(exp));
		}
		for (final String exp : exptectedNormalized) {
			assertTrue(exp + " was not found!", actualNormalized.contains(exp));
		}
	}
}
