/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.unibi.techfak.scie.annotators.structure;

import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import de.unibi.techfak.isy.lppba.descriptors.Sentence;
import de.unibi.techfak.isy.lppba.descriptors.Token;
import de.unibi.techfak.scie.document_import.DocumentImporter;
import de.unibi.techfak.scie.document_import.PDFStructuredTextExtractorWrapper;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import junit.framework.TestCase;
import org.apache.uima.UIMAException;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class StanfordTokenizerTest extends TestCase {

	public StanfordTokenizerTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class StanfordTokenizer.
	 */
	public void testProcess() throws Exception {
		final String testStr = "This is a test sentence. Is this a second one? I certainly hope so!";
		final String expPOSStr = "DT VBZ DT NN NN. VBZ DT DT JJ CD? PRP RB VBP RB!";
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(testStr);
		final StanfordTokenizer tokenizer = new StanfordTokenizer();
		tokenizer.process(jcas);

		final Pattern sentencePattern = Pattern.compile("[^\\s][^\\.\\!\\?]+[\\.\\!\\?]");
		final Matcher sentenceMatcher = sentencePattern.matcher(testStr);

		final Iterator<Sentence> actualSentences = JCasUtil.select(jcas, Sentence.class).iterator();

		while (sentenceMatcher.find()) {
			assertTrue(actualSentences.hasNext());
			assertEquals(sentenceMatcher.group(), actualSentences.next().getCoveredText());
		}
		assertFalse(actualSentences.hasNext());

		final String[] expWords = testStr.split("[^\\w]+");
		final String[] expPOS = expPOSStr.split("[^\\w]+");

		assertEquals(expWords.length, expPOS.length);

		final Iterator<Token> actualWords = JCasUtil.select(jcas, Token.class).iterator();

		for (int i = 0; i < expWords.length; i++) {
			assertTrue(actualWords.hasNext());
			Token actualWord = actualWords.next();
			if (actualWord.getCoveredText().matches("[\\!\\.\\?]")) {
				actualWord = actualWords.next();
			}
			assertEquals(expWords[i], actualWord.getCoveredText());
			assertEquals(expPOS[i], actualWord.getPOS());
		}
		assertEquals("!", actualWords.next().getCoveredText());
		assertFalse(actualWords.hasNext());
	}

	private static void runTokenization(File[] files,
			org.apache.uima.fit.component.JCasAnnotator_ImplBase... annotators) throws UIMAException,
			IOException {
		for (File file : files) {
			if (file.getName().endsWith(".pdf")) {
				System.out.println("Processing file " + file.getName());
				JCas jcas = JCasFactory.createJCas(
						"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
				final DocumentImporter instance = new PDFStructuredTextExtractorWrapper(
						new FileInputStream(file), jcas);

				instance.doImport();

				for (final org.apache.uima.fit.component.JCasAnnotator_ImplBase annotator
						: annotators) {
					annotator.process(jcas);
				}
			}
		}
	}
}
