/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.treatment;

import de.unibi.techfak.scie.annotators.treatment.AntiBodyAnnotator;
import java.util.Collection;
import java.util.Iterator;

import junit.framework.TestCase;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.scie.annotators.quantities.WordNumberAnnotator;
import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import de.unibi.techfak.isy.lppba.descriptors.AntiBody;

public class AntiBodyAnnotatorTest  extends TestCase {

	public AntiBodyAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class AntiBodyAnnotator.
	 */
	public void testProcess() throws Exception {
		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText("test case 350 Anti-CD11d mAb217L and 2* Anti-CD11d mAb226H");
		final String[] expected={"Anti-CD11d mAb217L","Anti-CD11d mAb226H"};
		//preprosess using StanfordTokenizer, NumberAnnotator and WordNumberAnnotator
		final StanfordTokenizer st = new StanfordTokenizer();
		st.process(jcas);
		final NumberAnnotator numberAnnotator = new NumberAnnotator();
		numberAnnotator.process(jcas);
		final WordNumberAnnotator wordNumberAnnotator = new WordNumberAnnotator();
		wordNumberAnnotator.process(jcas);
		final AntiBodyAnnotator instance = new AntiBodyAnnotator();
		instance.process(jcas);
		final Collection<AntiBody> antiBodyInstances = JCasUtil.select(jcas, AntiBody.class);
		final Iterator<AntiBody> iterator = antiBodyInstances.iterator();
		assertTrue(iterator.hasNext());
		assertEquals(expected[0], iterator.next().getCoveredText());
		assertTrue(iterator.hasNext());
		assertEquals(expected[1], iterator.next().getCoveredText());
		assertFalse(iterator.hasNext());
	}
}
