/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.treatment;

import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.Delivery;

import java.util.Collection;
import java.util.Iterator;

import junit.framework.TestCase;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author socnow
 */
public class DeliveryAnnotatorTest extends TestCase {

	public DeliveryAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class DeliveryAnnotator.
	 */
	public void testProcess() throws Exception {

		DatabaseSingleton.initialize("./config.xml");

		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
				"Animals recieved inosine/saline either intraperitoneally or subcutaneosly. A single dose of CEpo or Epo (10 ug/kg) was administered i.p. immediately after injury.");

		//create instance
		final OntologyAnnotator instance = new OntologyAnnotator();
		instance.process(jcas);

		//check results.
		final Collection<Delivery> adms
				= JCasUtil.select(jcas, Delivery.class);

		final Iterator<Delivery> iterator = adms.iterator();

		assertTrue(iterator.hasNext());
		Delivery adm = iterator.next();
		assertEquals("intraperitoneally", adm.getCoveredText());
		//assertEquals("intraperitoneal", adm.getStandardName());
		assertTrue(iterator.hasNext());
		adm = iterator.next();
		assertEquals("subcutaneosly", adm.getCoveredText());
		//assertEquals("subcutaneous", adm.getStandardName());
		assertTrue(iterator.hasNext());
		adm = iterator.next();
		assertEquals("i.p", adm.getCoveredText());
		//assertEquals("intraperitoneal", adm.getStandardName());
		assertFalse(iterator.hasNext());
	}
}
