/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.configuration;

import de.unibi.techfak.scie.configuration.ConfigurationEntry;
import de.unibi.techfak.scie.configuration.Configuration;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import junit.framework.TestCase;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public class ConfigurationTest extends TestCase {

	public ConfigurationTest(String testName) {
		super(testName);
	}

	private Configuration getTestInstance() {
		Configuration config = new Configuration();
		config.registerConfigurationSet("db", new ConfigurationEntry[]{
			new ConfigurationEntry("host", "Hostname", "localhost"),
			new ConfigurationEntry("port", "Port number", "12347"),
			new ConfigurationEntry("db", "Database name", "lppba"),
			new ConfigurationEntry("user", "User name", "Harald Toepfer"),
			new ConfigurationEntry("password", "Password", "schweinewarze")});
		return config;
	}

	/**
	 * Test of setValue, getValue method, of class Configuration.
	 */
	public void testValue() throws Exception {
		Configuration config = getTestInstance();

		assertEquals("Default value", "localhost", config.getValue("db", "host"));
		assertEquals("Default value", "schweinewarze", config.getValue("db", "password"));

		assertEquals("Invalid set", false, config.setValue("db2", "bla", "blub"));
		assertEquals("Invalid set", false, config.setValue("db", "bla", "blub"));
		assertEquals("Valid set", true, config.setValue("db", "HOST", "tomvollhorstraetsel"));

		assertEquals("Get value", "tomvollhorstraetsel", config.getValue("db", "hOst"));
	}

	/**
	 * Test of storeXMLConfigurationn, loadXMLConfiguration method, of class
	 * Configuration.
	 */
	public void testXML() throws Exception {
		Configuration config1 = getTestInstance();
		Configuration config2 = getTestInstance();

		config1.setValue("db", "host", "tomvollhorstraetsel");

		config1.storeXMLConfiguration(new FileOutputStream("testdata/configuration_test.xml"));

		config2.loadXMLConfiguration(new FileInputStream("testdata/configuration_test.xml"));

		assertEquals("Get value", "tomvollhorstraetsel", config2.getValue("db", "host"));
	}

}
