/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.driver;

import de.unibi.techfak.scie.ontology.driver.OntologyHandle;
import de.unibi.techfak.scie.ontology.driver.NodeDescriptor;
import de.unibi.techfak.scie.ontology.driver.AssociationType;
import de.unibi.techfak.scie.ontology.driver.Association;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public class OntologyDatabaseDriverTestData {

	public static NodeDescriptor[] getTestDescriptors(OntologyHandle ontology) {
		return new NodeDescriptor[]{
			/* Root node */
			new NodeDescriptor(ontology, 0, "noahs island", true),
			/* Catagories */
			new NodeDescriptor(ontology, 1, "animal"),
			new NodeDescriptor(ontology, 2, "protagonist"),
			new NodeDescriptor(ontology, 3, "location"),
			/* Locations */
			new NodeDescriptor(ontology, 4, "nohas island"),
			new NodeDescriptor(ontology, 5, "diamantia"),
			/* Protagonists */
			new NodeDescriptor(ontology, 6, "noah"),
			new NodeDescriptor(ontology, 7, "sacha"),
			new NodeDescriptor(ontology, 8, "pangolin"),
			new NodeDescriptor(ontology, 9, "gertie"),
			new NodeDescriptor(ontology, 10, "rocco"),
			new NodeDescriptor(ontology, 11, "mammothsbody"),
			new NodeDescriptor(ontology, 12, "salomi"),
			new NodeDescriptor(ontology, 13, "sparky"),
			new NodeDescriptor(ontology, 14, "woomera"),
			new NodeDescriptor(ontology, 15, "jasper"),
			new NodeDescriptor(ontology, 16, "the valve rhino"),
			new NodeDescriptor(ontology, 17, "reg"),
			new NodeDescriptor(ontology, 18, "ursula"),
			new NodeDescriptor(ontology, 19, "chang"),
			new NodeDescriptor(ontology, 20, "the problem walrus"),
			new NodeDescriptor(ontology, 21, "the hyenas"),
			new NodeDescriptor(ontology, 22, "wowee"),
			new NodeDescriptor(ontology, 23, "calanor"),
			new NodeDescriptor(ontology, 24, "imshee"),
			new NodeDescriptor(ontology, 25, "tallulah"),
			new NodeDescriptor(ontology, 26, "natasha"),
			new NodeDescriptor(ontology, 27, "queen abront"),
			new NodeDescriptor(ontology, 28, "gorm"),
			new NodeDescriptor(ontology, 29, "galeo"),
			new NodeDescriptor(ontology, 30, "morris"),
			new NodeDescriptor(ontology, 31, "rita"),
			new NodeDescriptor(ontology, 32, "the do dah"),
			new NodeDescriptor(ontology, 44, "nab"),
			new NodeDescriptor(ontology, 53, "wommie"),
			new NodeDescriptor(ontology, 55, "tusker"),
			new NodeDescriptor(ontology, 64, "chip"),
			/* Animal classes */
			new NodeDescriptor(ontology, 33, "mammal"),
			new NodeDescriptor(ontology, 34, "amphibian"),
			new NodeDescriptor(ontology, 35, "primate"),
			new NodeDescriptor(ontology, 36, "rodent"),
			new NodeDescriptor(ontology, 67, "bear"),
			new NodeDescriptor(ontology, 68, "marsupial"),
			new NodeDescriptor(ontology, 69, "canidae"),
			new NodeDescriptor(ontology, 70, "bird"),
			/* Animals */
			new NodeDescriptor(ontology, 37, "russian desman"),
			new NodeDescriptor(ontology, 38, "polar bear"),
			new NodeDescriptor(ontology, 39, "pangolin"),
			new NodeDescriptor(ontology, 40, "gorilla"),
			new NodeDescriptor(ontology, 41, "mammoth"),
			new NodeDescriptor(ontology, 42, "rabbit"),
			new NodeDescriptor(ontology, 43, "kangaroo"),
			new NodeDescriptor(ontology, 45, "orang utan"),
			new NodeDescriptor(ontology, 46, "proboscis monkey"),
			new NodeDescriptor(ontology, 47, "rhinoceros"),
			new NodeDescriptor(ontology, 48, "mandrill"),
			new NodeDescriptor(ontology, 49, "eurasian brown bear"),
			new NodeDescriptor(ontology, 50, "panda"),
			new NodeDescriptor(ontology, 51, "walrus"),
			new NodeDescriptor(ontology, 52, "hyena"),
			new NodeDescriptor(ontology, 54, "wombat"),
			new NodeDescriptor(ontology, 56, "african elephant"),
			new NodeDescriptor(ontology, 57, "french poodle"),
			new NodeDescriptor(ontology, 58, "aye aye"),
			new NodeDescriptor(ontology, 59, "warthog"),
			new NodeDescriptor(ontology, 60, "golden mole"),
			new NodeDescriptor(ontology, 62, "baboon"),
			new NodeDescriptor(ontology, 63, "dodo"),
			new NodeDescriptor(ontology, 65, "wallaby"),
			new NodeDescriptor(ontology, 66, "giant frog")};
	}

	public static Association[] getTestAssociations(OntologyHandle ontology) {
		return new Association[]{
			/* Root -> Categories */
			/* Root -> Categories */
			new Association(ontology, 0, 1),
			new Association(ontology, 0, 2),
			new Association(ontology, 0, 3),
			/* Locations */
			new Association(ontology, 4, 3, AssociationType.IS_A), // Noha's Island is a location
			new Association(ontology, 5, 3, AssociationType.IS_A), // Diamantia is a location

			new Association(ontology, 4, 6, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 7, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 8, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 9, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 10, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 11, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 12, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 13, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 14, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 15, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 16, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 17, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 18, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 19, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 20, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 21, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 22, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 23, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 24, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 25, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 26, AssociationType.CONTAINS_A),
			new Association(ontology, 4, 44, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 27, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 28, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 29, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 30, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 31, AssociationType.CONTAINS_A),
			new Association(ontology, 5, 32, AssociationType.CONTAINS_A),
			/* Protagonists */
			new Association(ontology, 6, 3, AssociationType.IS_A),
			new Association(ontology, 6, 38, AssociationType.IS_A),
			new Association(ontology, 7, 3, AssociationType.IS_A),
			new Association(ontology, 7, 37, AssociationType.IS_A),
			new Association(ontology, 8, 3, AssociationType.IS_A),
			new Association(ontology, 8, 39, AssociationType.IS_A),
			new Association(ontology, 9, 3, AssociationType.IS_A),
			new Association(ontology, 9, 40, AssociationType.IS_A),
			new Association(ontology, 10, 3, AssociationType.IS_A),
			new Association(ontology, 10, 40, AssociationType.IS_A),
			new Association(ontology, 11, 3, AssociationType.IS_A),
			new Association(ontology, 11, 41, AssociationType.IS_A),
			new Association(ontology, 12, 3, AssociationType.IS_A),
			new Association(ontology, 12, 41, AssociationType.IS_A),
			new Association(ontology, 13, 3, AssociationType.IS_A),
			new Association(ontology, 13, 42, AssociationType.IS_A),
			new Association(ontology, 14, 3, AssociationType.IS_A),
			new Association(ontology, 14, 43, AssociationType.IS_A),
			new Association(ontology, 15, 3, AssociationType.IS_A),
			new Association(ontology, 15, 46, AssociationType.IS_A),
			new Association(ontology, 16, 3, AssociationType.IS_A),
			new Association(ontology, 16, 47, AssociationType.IS_A),
			new Association(ontology, 17, 3, AssociationType.IS_A),
			new Association(ontology, 17, 48, AssociationType.IS_A),
			new Association(ontology, 18, 3, AssociationType.IS_A),
			new Association(ontology, 18, 49, AssociationType.IS_A),
			new Association(ontology, 18, 3, AssociationType.IS_A),
			new Association(ontology, 18, 49, AssociationType.IS_A),
			new Association(ontology, 19, 3, AssociationType.IS_A),
			new Association(ontology, 19, 50, AssociationType.IS_A),
			new Association(ontology, 20, 3, AssociationType.IS_A),
			new Association(ontology, 20, 51, AssociationType.IS_A),
			new Association(ontology, 21, 3, AssociationType.IS_A),
			new Association(ontology, 21, 52, AssociationType.IS_A),
			new Association(ontology, 22, 3, AssociationType.IS_A),
			new Association(ontology, 22, 57, AssociationType.IS_A),
			new Association(ontology, 23, 3, AssociationType.IS_A),
			new Association(ontology, 23, 58, AssociationType.IS_A),
			new Association(ontology, 24, 3, AssociationType.IS_A),
			new Association(ontology, 24, 59, AssociationType.IS_A),
			new Association(ontology, 25, 3, AssociationType.IS_A),
			new Association(ontology, 25, 47, AssociationType.IS_A),
			new Association(ontology, 26, 3, AssociationType.IS_A),
			new Association(ontology, 26, 60, AssociationType.IS_A),
			new Association(ontology, 27, 3, AssociationType.IS_A),
			new Association(ontology, 27, 66, AssociationType.IS_A),
			new Association(ontology, 28, 3, AssociationType.IS_A),
			new Association(ontology, 28, 41, AssociationType.IS_A),
			new Association(ontology, 29, 3, AssociationType.IS_A),
			new Association(ontology, 29, 66, AssociationType.IS_A),
			new Association(ontology, 30, 3, AssociationType.IS_A),
			new Association(ontology, 30, 66, AssociationType.IS_A),
			new Association(ontology, 31, 3, AssociationType.IS_A),
			new Association(ontology, 31, 62, AssociationType.IS_A),
			new Association(ontology, 32, 3, AssociationType.IS_A),
			new Association(ontology, 32, 63, AssociationType.IS_A),
			new Association(ontology, 44, 3, AssociationType.IS_A),
			new Association(ontology, 44, 45, AssociationType.IS_A),
			new Association(ontology, 53, 3, AssociationType.IS_A),
			new Association(ontology, 53, 54, AssociationType.IS_A),
			new Association(ontology, 55, 3, AssociationType.IS_A),
			new Association(ontology, 55, 56, AssociationType.IS_A),
			new Association(ontology, 64, 3, AssociationType.IS_A),
			new Association(ontology, 64, 65, AssociationType.IS_A),
			/* Animal classes */
			new Association(ontology, 33, 1, AssociationType.IS_A),
			new Association(ontology, 34, 1, AssociationType.IS_A),
			new Association(ontology, 70, 1, AssociationType.IS_A),
			new Association(ontology, 35, 33, AssociationType.IS_A),
			new Association(ontology, 36, 33, AssociationType.IS_A),
			new Association(ontology, 67, 33, AssociationType.IS_A),
			new Association(ontology, 68, 33, AssociationType.IS_A),
			new Association(ontology, 69, 33, AssociationType.IS_A),
			new Association(ontology, 37, 36, AssociationType.IS_A),
			new Association(ontology, 38, 67, AssociationType.IS_A),
			new Association(ontology, 39, 33, AssociationType.IS_A),
			new Association(ontology, 40, 35, AssociationType.IS_A),
			new Association(ontology, 41, 33, AssociationType.IS_A),
			new Association(ontology, 42, 36, AssociationType.IS_A),
			new Association(ontology, 43, 68, AssociationType.IS_A),
			new Association(ontology, 45, 35, AssociationType.IS_A),
			new Association(ontology, 46, 35, AssociationType.IS_A),
			new Association(ontology, 47, 33, AssociationType.IS_A),
			new Association(ontology, 48, 35, AssociationType.IS_A),
			new Association(ontology, 49, 67, AssociationType.IS_A),
			new Association(ontology, 50, 67, AssociationType.IS_A),
			new Association(ontology, 51, 33, AssociationType.IS_A),
			new Association(ontology, 52, 69, AssociationType.IS_A),
			new Association(ontology, 54, 68, AssociationType.IS_A),
			new Association(ontology, 56, 33, AssociationType.IS_A),
			new Association(ontology, 57, 69, AssociationType.IS_A),
			new Association(ontology, 58, 35, AssociationType.IS_A),
			new Association(ontology, 60, 36, AssociationType.IS_A),
			new Association(ontology, 62, 35, AssociationType.IS_A),
			new Association(ontology, 63, 70, AssociationType.IS_A),
			new Association(ontology, 65, 68, AssociationType.IS_A),
			new Association(ontology, 66, 34, AssociationType.IS_A)
		};
	}

}
