/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.driver.implementation;

import de.unibi.techfak.scie.configuration.ConfigurationSingleton;
import de.unibi.techfak.scie.configuration.ValidityException;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.scie.ontology.driver.OntologyDatabaseDriver;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public class JDBCTestInstance {

	public static OntologyDatabaseDriver getTestInstance() {
		// Make sure the database singleton is reset to its initial state (also
		// resets the configuration object!)
		DatabaseSingleton.reset();

		// Initialize the database and load the configuration
		DatabaseSingleton.initialize();
		try {
			ConfigurationSingleton.loadConfigurationIfExists("./config_dbtest.xml");
		} catch (ValidityException ex) {
			throw new RuntimeException(ex);
		}

		// Fetch the current database instance
		OntologyDatabaseDriver driver = DatabaseSingleton.getInstance().getOntologyDatabaseDriver();

		// Wipe it clean for the tests
		driver.clear();
		
		return driver;
	}

}
