/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.probability_model.uima;

import de.unibi.techfak.scie.probability_model.uima.UIMAAnnotationCompositionUtil;
import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.isy.lppba.descriptors.Integer;
import de.unibi.techfak.scie.probability_model.ProbableHypothesis;
import de.unibi.techfak.scie.probability_model.uima.UIMAAnnotationCompositionUtil.UIMASemanticProbabilityModel;
import junit.framework.TestCase;
import org.apache.uima.UIMAException;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class UIMAAnnotationCompositionUtilTest extends TestCase {

	public UIMAAnnotationCompositionUtilTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of calculateMaxProbHypothesis method, of class
	 * AnnotationCompositionUtil.
	 */
	public void testCalculateMaxProbHypothesis() throws UIMAException {
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
				"These are two test sentences with 4 numbers for one single unit test. There are 1m reasons to do Unit tests!");

		//preprosess using NumberAnnotator
		final NumberAnnotator numberAnnotator = new NumberAnnotator();
		numberAnnotator.process(jcas);

		//use the first number as core.
		final de.unibi.techfak.isy.lppba.descriptors.Integer core = JCasUtil.
				select(jcas,
				de.unibi.techfak.isy.lppba.descriptors.Integer.class).iterator().
				next();
		final double sigma = 50;
		//we create a trivial likelihood model that only gives high probability for numbers > 100.
		final UIMASemanticProbabilityModel<de.unibi.techfak.isy.lppba.descriptors.Integer> likelihoodModel =
				new UIMASemanticProbabilityModel<de.unibi.techfak.isy.lppba.descriptors.Integer>() {
			@Override
			public double calculateSemanticProbability(
					de.unibi.techfak.isy.lppba.descriptors.Integer candidate) {
				if (candidate.getValue() > 100) {
					return 1;
				} else {
					return 0.01;
				}
			}
		};
		//calculate the MAP
		final ProbableHypothesis<UIMAAnnotationCompositionUtil.UIMAAnnotationCandidate<Integer>> maxProb =
				UIMAAnnotationCompositionUtil.calculateMaxProbHypothesis(core,
				likelihoodModel,
				de.unibi.techfak.isy.lppba.descriptors.Integer.class, jcas,
				sigma);
		assertNotNull(maxProb.getCandidate());
		assertEquals("1m", maxProb.getCandidate().getAnnotation().
				getCoveredText());
		assertEquals(1000000, maxProb.getCandidate().getAnnotation().getValue());
		assertTrue(maxProb.getProbability() > 0);
	}
}
